.. Copyright (C) 2013-2018 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2015-2017 Robin Schneider <ypid@riseup.net>
.. Copyright (C) 2014-2018 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

See Also
========

:man:`apt(8)`
  Advanced Package Tool command line interface

:man:`sources.list(5)`
  :file:`/etc/apt/sources.list` documentation
